@@ -228,14 +228,19 @@ Log.WriteLine("doing backup");
 			splashMessageChange(4);  //updating DB
 			updatingDB = true;
 
+			if(Sqlite.ChangeDjToDJna())
+				messageToShowOnBoot += Catalog.GetString("All DJ jumps have been renamed as 'DJna' (Drop Jumps with No Arms).") + "\n\n"+ 
+					Catalog.GetString("If your Drop Jumps were executed using the arms, please rename them manually as 'DJa'.") + "\n";
+
 			bool softwareIsNew = Sqlite.ConvertToLastChronojumpDBVersion();
 			updatingDB = false;
-
+			
+				
 			if(! softwareIsNew) {
 				//Console.Clear();
 				string errorMessage = string.Format(Catalog.GetString ("Sorry, this Chronojump version ({0}) is too old for your database."), progVersion) + "\n" +  
 						Catalog.GetString("Please update Chronojump") + ":\n"; 
-				errorMessage += "http://www.gnome.org/projects/chronojump/installation"; 
+				errorMessage += "http://chronojump.org"; 
 				//errorMessage += "\n\n" + Catalog.GetString("Press any key");
 				Log.WriteLine(errorMessage);
 				messageToShowOnBoot += errorMessage;
@@ -277,26 +282,36 @@ Log.WriteLine("doing backup");
 		}
 
 		string versionAvailableKnown = SqlitePreferences.Select("versionAvailable");
-		if( versionAvailable != Constants.ServerOffline && versionAvailable != progVersion ) {
+		if( versionAvailable != Constants.ServerOffline && new Version(versionAvailable) > new Version(progVersion) ) {
 			//check if available version is higher than known available version
 			Version versionAvailableAsV = new Version(versionAvailable);
-			Version versionAvailableKnownAsV = new Version(versionAvailableKnown);
-			if(versionAvailableAsV > versionAvailableKnownAsV) {
+
+			Version versionAvailableKnownAsV;
+			bool updateKnownVersion = false;
+			if(versionAvailableKnown == "")
+				updateKnownVersion = true;
+			else {
+				versionAvailableKnownAsV = new Version(versionAvailableKnown);
+				if(versionAvailableAsV > versionAvailableKnownAsV)
+					updateKnownVersion = true;
+			}
+
+			if(updateKnownVersion) {
 				//is the first time we know about this new version
 				//just write on db and show message to user
 				SqlitePreferences.Update(Constants.PrefVersionAvailable, versionAvailable, false);
 				versionAvailableKnown = versionAvailable;
 				messageToShowOnBoot += string.Format(Catalog.GetString(
-							"\nNew Chronojump version available: {0}\nYour Chronojump version is: {1}"), 
+							"\nNew Chronojump version available on website.\nYour Chronojump version is: {1}"), 
 						versionAvailable, progVersion) + "\n\n" + 
-					Catalog.GetString("Please, update to new version: ") + versionAvailable + "\n";
+					Catalog.GetString("Please, update to new version.") + "\n";
 			}
 		}
 
 
 		//if chronojump chrashed before
 		if(crashedBefore) {
-			if( versionAvailableKnown.Length > 0 && versionAvailableKnown != progVersion ) 
+			if( versionAvailableKnown.Length > 0 && new Version(versionAvailableKnown) > new Version(progVersion) ) 
 				messageToShowOnBoot += "\n" + Catalog.GetString("Chronojump crashed before.") + "\n" +
 				       Catalog.GetString("Please, update to new version: ") + versionAvailableKnown + "\n";
 			else
