@@ -25,6 +25,8 @@ public class Constants
 {
 	//the strings created by Catalog cannot be const
 	
+	public static string ReadmeTranslators = Catalog.GetString("Translator, there's a glossary that will help you in Chronojump translation:\n http://svn.gnome.org/svn/chronojump/trunk/glossary/chronojump_glossary_for_translators.html");
+
 	public static string [] Authors = {
 		"Xavier de Blas (xaviblas@gmail.com)\n" + Catalog.GetString("Project leader and main developer."), 
 		"Juan Gonzalez (http://www.iearobotics.com)\n" + Catalog.GetString("Skypic, Chronopic, connection between hardware and software."), 
@@ -62,10 +64,14 @@ public class Constants
 	//sqlite tables
 	//instead of typing the tableName directly (that can crash if it's bad written and it's not detected by compiler)
 	//use the following consts, and if it's misspelled, compiler will know
-	public const string PersonTable = "person";
+	public const string PersonTable = "person77";
+	public const string PersonSessionTable = "personSession77";
+	
+	public const string PersonOldTable = "person";
+	public const string PersonSessionOldTable = "personSession"; //old table, used before db 0.53
+	public const string PersonSessionOldWeightTable = "personSessionWeight"; //old table, used from db 0.53 to 0.76
+
 	public const string SessionTable = "session";
-	public const string PersonSessionTable = "personSession";
-	public const string PersonSessionWeightTable = "personSessionWeight";
 	public const string PersonNotUploadTable = "personSessionNotUpload"; 
 	public const string SportTable = "sport";
 	public const string SpeciallityTable = "speciallity";
@@ -94,6 +100,7 @@ public class Constants
 
 	public const string UndefinedDefault = "Undefined";
 	public const string Any = "Any";
+	private static string dumbVariableForTranslatingAny = Catalog.GetString("Any");
 
 	public const string M = "M";
 	public const string F = "F";
@@ -103,6 +110,11 @@ public class Constants
 	public const int MaleID = 1;
 	public const int FemaleID = 0;
 
+	//person & personSession stuff
+	public const string Name = "name";
+	public const string Height = "height";
+	public const string Weight = "weight";
+
 	//server	
 	public const string ServerPingTable = "SPing"; 
 	public const string ServerEvaluatorTable = "SEvaluator"; 
@@ -230,8 +242,8 @@ public class Constants
 	public static string AllPulsesName = Catalog.GetString("See all pulses");
 
 	//fileNames
-	public static string FileNameLogo = "chronojump_logo.png";
-	public static string FileNameLogo320 = "chronojump_320.png";
+	public static string FileNameLogo = "chronojump-boscosystem.png";
+	public static string FileNameLogo320 = "chronojump-boscosystem_320.png";
 	public static string FileNameCSS = "report_web_style.css";
 	public static string FileNameIcon = "chronojump_icon.png";
 	public static string FileNameIconGraph = "chronojump_icon_graph.png";
@@ -241,15 +253,17 @@ public class Constants
 	public static string FileNameRScript = "r-graph.txt";
 	public static string GraphTypeBoxplot = "Boxplot";
 	public static string GraphTypeBarplot = "Barplot";
+	public static string GraphTypeHistogram = "Histogram";
 	public static string GraphTypeLines = "Lines";
-	public static string GraphTypeXY = "XY";
+	public static string GraphTypeXY = "Dispersion";
 	public static string GraphTypeDotchart = "Dotchart";
 	public static string GraphTypeStripchart = "Stripchart";
-	public static string [] GraphTypes = { GraphTypeBoxplot, GraphTypeBarplot, GraphTypeLines, 
+	public static string [] GraphTypes = { GraphTypeBoxplot, GraphTypeHistogram, GraphTypeBarplot, GraphTypeLines, 
 		GraphTypeXY, GraphTypeDotchart, GraphTypeStripchart };
 	public static string GraphPaletteGray = "gray.colors";
-	public static string [] GraphPalettes = { GraphPaletteGray, "rainbow", 
-		"topo.colors", "heat.colors", "terrain.colors", "cm.colors" };
+	public static string GraphPaletteBlack = Catalog.GetString("black only");
+	public static string [] GraphPalettes = { GraphPaletteBlack, GraphPaletteGray, "rainbow", 
+		"topo.colors", "heat.colors", "terrain.colors", "cm.colors"};
 
 
 	public static string FileNameZoomFitIcon = "gtk-zoom-fit.png";
@@ -372,6 +386,8 @@ public class Constants
 	};
 	
 	public static int Simulated = -1; 
+	public static string SimulatedMessage = Catalog.GetString("Tests are SIMULATED until Chronopic is connected at menu 'Tools / Chronopic'.");
+
 	
 	//levels of sport practice
 	//int will go into person database
