@@ -288,7 +288,10 @@ Log.WriteLine("MANAGE(3)!!!!");
 		string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + " " + 
 			type + " " + Catalog.GetString("time") + ": " + Util.TrimDecimals( time.ToString(), pDN ) + 
 			" " + Catalog.GetString("speed") + ": " + Util.TrimDecimals ( (distance/time).ToString(), pDN );
-		appbar.Push( 1,myStringPush );
+		if(simulated)
+			appbar.Push(1, Constants.SimulatedMessage);
+		else
+			appbar.Push( 1,myStringPush );
 
 
 		string description = "";
@@ -296,7 +299,7 @@ Log.WriteLine("MANAGE(3)!!!!");
 			// P = W * 9.8 * D / t   
 			// W: person weight
 			// D: distance between 3d and 9th stair
-			double weight = SqlitePersonSession.SelectPersonWeight(personID, sessionID);
+			double weight = SqlitePersonSession.SelectAttribute(personID, sessionID, Constants.Weight);
 			double distanceMeters = distance / 1000;
 			description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / time).ToString(), pDN) + " (Watts)";
 		} else if(type == "Gesell-DBT") 
@@ -325,7 +328,7 @@ Log.WriteLine("MANAGE(3)!!!!");
 	
 	public string RunnerName
 	{
-		get { return SqlitePerson.SelectJumperName(personID); }
+		get { return SqlitePerson.SelectAttribute(personID, Constants.Name); }
 	}
 
 	~RunExecute() {}
@@ -795,7 +798,10 @@ public class RunIntervalExecute : RunExecute
 						Util.GetSpeed(distanceTotal.ToString(),
 							timeTotal.ToString(), metersSecondsPreferred )
 						, pDN ) ;
-			appbar.Push( 1,myStringPush );
+			if(simulated)
+				appbar.Push(1, Constants.SimulatedMessage);
+			else
+				appbar.Push( 1,myStringPush );
 
 
 			//event will be raised, and managed in chronojump.cs
