@@ -47,7 +47,7 @@ class SqliteJump : Sqlite
 			"type TEXT, " +
 			"tv FLOAT, " +
 			"tc FLOAT, " +
-			"fall INT, " +  
+			"fall FLOAT, " +  
 			"weight TEXT, " + //string because can contain "33%" or "50Kg"
 			"description TEXT, " +
 			"angle FLOAT, " + //-1.0 if undef
@@ -64,7 +64,7 @@ class SqliteJump : Sqlite
 	 */
 	
 	//public static int Insert(int personID, int sessionID, string type, double tv, double tc, int fall, double weight, string limited, string description, int simulated)
-	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double tv, double tc, int fall, double weight, string description, double angle, int simulated)
+	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weight, string description, double angle, int simulated)
 	{
 		if(! dbconOpened)
 			dbcon.Open();
@@ -76,7 +76,7 @@ class SqliteJump : Sqlite
 				" (uniqueID, personID, sessionID, type, tv, tc, fall, weight, description, angle, simulated)" +
 				" VALUES (" + uniqueID + ", "
 				+ personID + ", " + sessionID + ", '" + type + "', "
-				+ Util.ConvertToPoint(tv) + ", " + Util.ConvertToPoint(tc) + ", " + fall + ", '" 
+				+ Util.ConvertToPoint(tv) + ", " + Util.ConvertToPoint(tc) + ", " + Util.ConvertToPoint(fall) + ", '" 
 				+ Util.ConvertToPoint(weight) + "', '" + description + "', "
 				+ Util.ConvertToPoint(angle) + ", " + simulated +")" ;
 		Log.WriteLine(dbcmd.CommandText.ToString());
@@ -93,13 +93,16 @@ class SqliteJump : Sqlite
 	//if all types put, "" in filterType
 	public static string[] SelectJumps(int sessionID, int personID, string filterWeight, string filterType) 
 	{
+		string tp = Constants.PersonTable;
+		string tps = Constants.PersonSessionTable;
+
 		string filterSessionString = "";
 		if(sessionID != -1)
 			filterSessionString = " AND jump.sessionID == " + sessionID;
 
 		string filterPersonString = "";
 		if(personID != -1)
-			filterPersonString = " AND person.uniqueID == " + personID;
+			filterPersonString = " AND " + tp + ".uniqueID == " + personID;
 
 		string filterWeightString = "";
 		if(filterWeight == "withWeight")
@@ -110,16 +113,16 @@ class SqliteJump : Sqlite
 			filterTypeString = " AND jump.type == '" + filterType + "' ";
 
 		dbcon.Open();
-		dbcmd.CommandText = "SELECT person.name, jump.*, personSessionWeight.weight " +
-			" FROM person, jump, personSessionWeight " +
-			" WHERE person.uniqueID == jump.personID " + 
+		dbcmd.CommandText = "SELECT " + tp + ".name, jump.*, " + tps + ".weight " +
+			" FROM " + tp + ", jump, " + tps + 
+			" WHERE " + tp + ".uniqueID == jump.personID " + 
 			filterSessionString +
 			filterPersonString +
 			filterWeightString +
 			filterTypeString +
-			" AND personSessionWeight.personID == person.uniqueID " +
-			" AND personSessionWeight.sessionID == jump.sessionID " +
-			" ORDER BY upper(person.name), jump.uniqueID";
+			" AND " + tps + ".personID == " + tp + ".uniqueID " +
+			" AND " + tps + ".sessionID == jump.sessionID " +
+			" ORDER BY upper(" + tp + ".name), jump.uniqueID";
 		
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -142,7 +145,7 @@ class SqliteJump : Sqlite
 					reader[4].ToString() + ":" + 	//jump.type
 					Util.ChangeDecimalSeparator(reader[5].ToString()) + ":" + 	//jump.tv
 					Util.ChangeDecimalSeparator(reader[6].ToString()) + ":" + 	//jump.tc
-					reader[7].ToString() + ":" + 	//fall
+					Util.ChangeDecimalSeparator(reader[7].ToString()) + ":" + 	//fall
 					Util.ChangeDecimalSeparator(reader[8].ToString()) + ":" + 	//weight
 					reader[9].ToString() + ":" +	//description
 					Util.ChangeDecimalSeparator(reader[10].ToString()) + ":" +	//angle
@@ -201,10 +204,10 @@ class SqliteJump : Sqlite
 		dbcon.Close();
 	}
 
-	public static void UpdateWeight(string tableName, int uniqueID, int weight)
+	public static void UpdateWeight(string tableName, int uniqueID, double weight)
 	{
 		dbcon.Open();
-		dbcmd.CommandText = "UPDATE " + tableName + " SET weight = " + weight + 
+		dbcmd.CommandText = "UPDATE " + tableName + " SET weight = " + Util.ConvertToPoint(weight) + 
 			" WHERE uniqueID == " + uniqueID ;
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
