@@ -527,6 +527,18 @@ public class Util
 
 		return 24.06 * ( tt * tf ) / (Double)tc;
 	}
+				
+	//only Lewis now
+	public static double GetPower (double tf, double bodyWeight, double extraWeightKg) 
+	{
+		//Log.WriteLine("tf: " + tf + ", bodyWeight: " + bodyWeight + ", extra: " + extraWeightKg);
+		double pw = System.Math.Sqrt ( 4.9 ) * 9.8 * (bodyWeight + extraWeightKg) *
+			System.Math.Sqrt(
+				       Convert.ToDouble(GetHeightInCentimeters(tf.ToString()))/100);
+		//Log.WriteLine("pw: " + pw);
+		return pw;
+
+	}
 
 
 	public static double GetQIndex (double tv, double tc) 
@@ -875,10 +887,13 @@ public class Util
 		}
 	}
 			
-	public static string ArrayListToSingleString (ArrayList myArrayList) {
+	public static string ArrayListToSingleString (ArrayList myArrayList, string sep) {
 		string myString = "";
-		foreach (string str in myArrayList) 
-			myString += str + "\n";
+		string sepUsed = "";
+		foreach (string str in myArrayList) { 
+			myString += sepUsed + str;
+			sepUsed =  sep;
+		}
 
 		return myString;
 	}
@@ -1122,57 +1137,4 @@ public class Util
 		return searchedValue;
 	}
 
-	public static string SQLBuildString (string tableName, string test, string variable,
-			int sex, string ageInterval,
-			int countryID, int sportID, int speciallityID, int levelID)
-	{
-		string strSelect = "SELECT COUNT(" + variable + "), AVG(" + variable + ")";
-		string strFrom   = " FROM " + tableName;
-		string strWhere  = " WHERE " + tableName + ".type = '" + test + "'";
-
-		string strSex = "";
-		if(sex == Constants.MaleID) 
-			strSex = " AND person.sex == '" + Constants.M + "'";
-		else if (sex == Constants.FemaleID) 
-			strSex = " AND person.sex == '" + Constants.F + "'";
-
-		string strAge = "";
-		if(ageInterval != "") {
-			strFrom += ", session";
-			string [] strFull = ageInterval.Split(new char[] {':'});
-			strAge = " AND (julianday(session.date) - julianday(person.dateBorn))/365.25 " + 
-				strFull[0] + " " + strFull[1];
-			if(strFull.Length == 4)
-				strAge += " AND (julianday(session.date) - julianday(person.dateBorn))/365.25 " + 
-					strFull[2] + " " + strFull[3];
-			strAge += " AND " + tableName + ".sessionID = session.uniqueID";
-		}
-
-		string strCountry = "";
-		if(countryID != Constants.CountryUndefinedID) 
-			strCountry = " AND person.countryID == " + countryID;
-
-		string strSport = "";
-		if(sportID != Constants.SportUndefinedID) 
-			strSport = " AND person.sportID == " + sportID;
-
-		string strSpeciallity = "";
-		if(speciallityID != Constants.SpeciallityUndefinedID) 
-			strSpeciallity = " AND person.speciallityID == " + speciallityID;
-		
-		string strLevel = "";
-		if(levelID != Constants.LevelUndefinedID) 
-			strLevel = " AND person.practice == " + levelID;
-
-		string strLast = "";
-		if(strSex.Length > 0 || strAge.Length > 0 || 
-				strCountry.Length > 0 || strSport.Length > 0 || strSpeciallity.Length > 0 || strLevel.Length > 0) {
-			strFrom += ", person";
-			strLast = " AND " + tableName + ".personID == person.UniqueID";
-		}	
-		return strSelect + strFrom + strWhere + strSex + strAge
-			+ strCountry + strSport + strSpeciallity + strLevel + strLast;
-
-	}
-
 }
